@@ -237,11 +237,14 @@ static void print_help(const char *my_name)
       xprintf("   --first           branch on first integer variable\n")
          ;
       xprintf("   --last            branch on last integer variable\n");
+      xprintf("   --mostf           branch on most fractional variable "
+         "\n");
       xprintf("   --drtom           branch using heuristic by Driebeck "
          "and Tomlin\n");
       xprintf("                     (default)\n");
-      xprintf("   --mostf           branch on most fractional variable "
-         "\n");
+      xprintf("   --pcost           branch using hybrid pseudocost heur"
+         "istic (may be\n");
+      xprintf("                     useful for hard instances)\n");
       xprintf("   --dfs             backtrack using depth first search "
          "\n");
       xprintf("   --bfs             backtrack using breadth first searc"
@@ -317,7 +320,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
          else if (p("-d") || p("--data"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  xprintf("No input data file specifed\n");
+            {  xprintf("No input data file specified\n");
                return 1;
             }
             if (csa->ndf == DATA_MAX)
@@ -329,7 +332,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
          else if (p("-y") || p("--display"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  xprintf("No display output file specifed\n");
+            {  xprintf("No display output file specified\n");
                return 1;
             }
             if (csa->out_dpy != NULL)
@@ -349,7 +352,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
          else if (p("-r") || p("--read"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  xprintf("No input solution file specifed\n");
+            {  xprintf("No input solution file specified\n");
                return 1;
             }
             if (csa->in_res != NULL)
@@ -381,7 +384,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
          else if (p("-w") || p("--write"))
          {  k++;
             if (k == argc || argv[k][0] == '\0' || argv[k][0] == '-')
-            {  xprintf("No output solution file specifed\n");
+            {  xprintf("No output solution file specified\n");
                return 1;
             }
             if (csa->out_res != NULL)
@@ -577,7 +580,7 @@ static int parse_cmdline(struct csa *csa, int argc, const char *argv[])
          else if (p("--mostf"))
             csa->iocp.br_tech = GLP_BR_MFV;
          else if (p("--pcost"))
-            csa->iocp.br_tech = GLP_BR_HPC;
+            csa->iocp.br_tech = GLP_BR_PCH;
          else if (p("--dfs"))
             csa->iocp.bt_tech = GLP_BT_DFS;
          else if (p("--bfs"))
@@ -713,6 +716,18 @@ int glp_main(int argc, const char *argv[])
       /* print version information */
       print_version(1);
       /*--------------------------------------------------------------*/
+      /* print parameters(s) specified in the command line */
+      {  int k, len = INT_MAX;
+         xprintf("Parameter(s) specified in the command line:");
+         for (k = 1; k < argc; k++)
+         {  if (len > 72)
+               xprintf("\n"), len = 0;
+            xprintf(" %s", argv[k]);
+            len += 1 + strlen(argv[k]);
+         }
+         xprintf("\n");
+      }
+      /*--------------------------------------------------------------*/
       /* read problem data from the input file */
       if (csa->in_file == NULL)
       {  xprintf("No input problem file specified; try %s --help\n",
@@ -939,6 +954,10 @@ err2:    {  xprintf("MathProg model processing error\n");
          {  glp_set_bfcp(csa->prob, &csa->bfcp);
             glp_simplex(csa->prob, &csa->smcp);
          }
+#if 0
+         csa->iocp.msg_lev = GLP_MSG_DBG;
+         csa->iocp.pp_tech = GLP_PP_NONE;
+#endif
          glp_intopt(csa->prob, &csa->iocp);
       }
       else
